package binsec

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Parameter Make.Engine

val image : Binsec_sse.Image.t

fs filepath returns the content of filepath. It uses the virtual file system which may differ from the host one.

  • raises Not_found

    if the file does not exist.

module Metrics : sig ... end
module Debug : sig ... end

lookup fid returns the key associated to the field identifier fid registered via PLUGIN.fields.

resume path resumes the execution of a path which was paused with Signal Stashed.

It adds back path to the running path worklist.

compile graph compiles the Ir code block into an executable form and returns a mapping from graph vertices to their associated fiber nodes.

The resulting nodes can be fed to the Continue and Return_to continuations.