package binsec

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Engine.Debug

val symbol : ?info:Binsec_kernel.Dba.Var.Tag.attribute -> string -> Z.t option

symbol ~info name returns the value of the queried info attribute of the symbol name (by default, module-Dba.module-Var.module-Tag.contructor-Value).

val reverse_section : Binsec_kernel.Virtual_address.t -> (string * Z.t) option

reverse_section addr returns the name and the offset from the start of the section from which the address belongs.

val reverse_symbol : Binsec_kernel.Virtual_address.t -> (string * Z.t) option

reverse_symbol addr returns the name and the offset from the start of the symbol from which the address belongs.